@@ -1,5 +1,7 @@
-import xnat
+import os
 
+import xnat
+from mlops.utils.logger import logger
 
 def xnat_build_dataset(xnat_configuration, minimal=True):
     """
@@ -25,14 +27,15 @@ def xnat_build_dataset(xnat_configuration, minimal=True):
     """
     with xnat.connect(server=xnat_configuration['server'],
                       user=xnat_configuration['user'],
-                      password=xnat_configuration['password']) as session:
+                      password=xnat_configuration['password'], verify=bool(os.getenv('MLOPS_SSL'))) as session:
 
+        logger.info(f"Collecting XNAT project: {xnat_configuration['project']}")
         project = session.projects[xnat_configuration["project"]]
 
         dataset = []
         for subject in project.subjects:
 
-            data_series = {'subject_id': subject, 'subject_uri': project.subjects[subject].uri}
+            data_series = {'subject_id': project.subjects[subject].label, 'subject_uri': project.subjects[subject].uri}
 
             if not minimal:
                 for experiment in project.subjects[subject].experiments:
@@ -42,7 +45,7 @@ def xnat_build_dataset(xnat_configuration, minimal=True):
                         scan_dict[project.subjects[subject].experiments[experiment].scans[scan].series_description] = project.subjects[subject].experiments[experiment].scans[scan]
 
                     data_series[project.subjects[subject].experiments[experiment].label] = scan_dict
-
+            logger.debug(f"Adding data series to dataset: {data_series}")
             dataset.append(data_series)
 
     return dataset
